@@ -15,7 +15,7 @@
  * GNU Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+ * License along with this library.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef KGAPI2_BLOGGER_POSTSEARCHJOB_H
@@ -41,7 +41,7 @@ class KGAPIBLOGGER_EXPORT PostSearchJob : public KGAPI2::FetchJob
                            const QString &query,
                            const AccountPtr &account = AccountPtr(),
                            QObject *parent = nullptr);
-    virtual ~PostSearchJob();
+    ~PostSearchJob() override;
 
     bool fetchBodies() const;
     void setFetchBodies(bool fetchBodies);
