@@ -70,10 +70,8 @@ void CalendarCreateJob::start()
 
     CalendarPtr calendar = d->calendars.current();
     const QUrl url = CalendarService::createCalendarUrl();
-    QNetworkRequest request;
-    request.setRawHeader("Authorization", "Bearer " + account()->accessToken().toLatin1());
+    QNetworkRequest request(url);
     request.setRawHeader("GData-Version", CalendarService::APIVersion().toLatin1());
-    request.setUrl(url);
 
     const QByteArray rawData = CalendarService::calendarToJSON(calendar);
 
