@@ -26,11 +26,13 @@
 #include "networkaccessmanagerfactory_p.h"
 #include "../debug.h"
 #include "authjob.h"
+#include "utils.h"
 
 #include <QCoreApplication>
 #include <QJsonDocument>
 #include <QTextStream>
 #include <QFile>
+#include <QUrlQuery>
 
 using namespace KGAPI2;
 
@@ -62,20 +64,19 @@ FileLogger *FileLogger::self()
     return sInstance;
 }
 
-void FileLogger::logRequest(const KGAPI2::Request &request)
+void FileLogger::logRequest(const QNetworkRequest &request, const QByteArray &rawData)
 {
     if (!mFile) {
         return;
     }
 
     QTextStream stream(mFile.data());
-    stream << "C: " << request.request.url().toDisplayString() << "\n";
-    stream << "   Content-type: " << request.contentType << "\n";
-    const auto headers = request.request.rawHeaderList();
+    stream << "C: " << request.url().toDisplayString() << "\n";
+    const auto headers = request.rawHeaderList();
     for (const auto &header : headers) {
-        stream << "   " << header << ": " << request.request.rawHeader(header) << "\n\n";
+        stream << "   " << header << ": " << request.rawHeader(header) << "\n";
     }
-    stream << "   " << request.rawData << "\n\n";
+    stream << "   " << rawData << "\n\n";
     mFile->flush();
 }
 
@@ -89,9 +90,9 @@ void FileLogger::logReply(const QNetworkReply *reply, const QByteArray &rawData)
     stream << "S: " << reply->url().toDisplayString() << "\n";
     const auto headers = reply->rawHeaderList();
     for (const auto &header : headers) {
-        stream << "   " << header << ": " << reply->rawHeader(header) << "\n\n";
+        stream << "   " << header << ": " << reply->rawHeader(header) << "\n";
     }
-    stream << "   " << rawData;
+    stream << "   " << rawData << "\n\n";
     mFile->flush();
 }
 
@@ -102,6 +103,7 @@ Job::Private::Private(Job *parent):
     error(KGAPI2::NoError),
     accessManager(nullptr),
     maxTimeout(0),
+    prettyPrint(false),
     q(parent)
 {
 }
@@ -322,10 +324,28 @@ void Job::Private::_k_dispatchTimeout()
     const Request r = requestQueue.dequeue();
     currentRequest = r;
 
-    qCDebug(KGAPIDebug) << q << "Dispatching request to" << r.request.url();
-    FileLogger::self()->logRequest(r);
+    QNetworkRequest authorizedRequest = r.request;
+    if (account) {
+        authorizedRequest.setRawHeader("Authorization", "Bearer " + account->accessToken().toLatin1());
+    }
 
-    q->dispatchRequest(accessManager, r.request, r.rawData, r.contentType);
+    QUrl url = authorizedRequest.url();
+    QUrlQuery standardParamQuery(url);
+    if (!fields.isEmpty()) {
+        standardParamQuery.addQueryItem(Job::StandardParams::Fields, fields.join(QStringLiteral(",")));
+    }
+
+    if (!standardParamQuery.hasQueryItem(Job::StandardParams::PrettyPrint)) {
+        standardParamQuery.addQueryItem(Job::StandardParams::PrettyPrint, Utils::bool2Str(prettyPrint));
+    }
+
+    url.setQuery(standardParamQuery);
+    authorizedRequest.setUrl(url);
+
+    qCDebug(KGAPIDebug) << q << "Dispatching request to" << r.request.url();
+    FileLogger::self()->logRequest(authorizedRequest, r.rawData);
+
+    q->dispatchRequest(accessManager, authorizedRequest, r.rawData, r.contentType);
 
     if (requestQueue.isEmpty()) {
         dispatchTimer->stop();
@@ -334,6 +354,9 @@ void Job::Private::_k_dispatchTimeout()
 
 /************************* PUBLIC **********************/
 
+const QString Job::StandardParams::PrettyPrint = QStringLiteral("prettyPrint");
+const QString Job::StandardParams::Fields = QStringLiteral("fields");
+
 Job::Job(QObject* parent):
     QObject(parent),
     d(new Private(this))
@@ -421,6 +444,35 @@ void Job::setAccount(const AccountPtr& account)
     d->account = account;
 }
 
+bool Job::prettyPrint() const
+{
+    return d->prettyPrint;
+}
+
+void Job::setPrettyPrint(bool prettyPrint)
+{
+    if (d->isRunning) {
+        qCWarning(KGAPIDebug) << "Called setPrettyPrint() on running job. Ignoring.";
+        return;
+    }
+
+    d->prettyPrint = prettyPrint;
+}
+
+QStringList Job::fields() const
+{
+    return d->fields;
+}
+
+void Job::setFields(const QStringList &fields)
+{
+    d->fields = fields;
+}
+
+QString Job::buildSubfields(const QString &field, const QStringList &fields) {
+    return QStringLiteral("%1(%2)").arg(field).arg(fields.join(QStringLiteral(",")));
+}
+
 void Job::restart()
 {
     if (d->isRunning) {
@@ -433,7 +485,6 @@ void Job::restart()
 
 void Job::emitFinished()
 {
-    qCDebug(KGAPIDebug);
     aboutToFinish();
 
     d->isRunning = false;
