@@ -15,7 +15,7 @@
     GNU Lesser General Public License for more details.
 
     You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    License along with this library.  If not, see <https://www.gnu.org/licenses/>.
 */
 
 #ifndef LIBKGAPI2_DRIVEPERMISSION_H
@@ -68,6 +68,8 @@ class KGAPIDRIVE_EXPORT Permission: public KGAPI2::Object
     explicit Permission();
     explicit Permission(const Permission &other);
     ~Permission() override;
+    bool operator==(const Permission &other) const;
+    bool operator!=(const Permission &other) const { return !operator==(other); }
 
     /**
      * @brief Returns the id of the permission.
